@@ -56,7 +56,6 @@ public:
   void PreInit()
   {
     Lum::Array  *array;
-    Lum::Button *button;
     Lum::Panel  *panel;
 
     panel=new Lum::VPanel();
@@ -71,25 +70,14 @@ public:
       text=new Lum::Text();
       text->SetFlex(true,true);
       text->SetText(Lum::Base::NumberToWString(i),
-                    Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                              popupFontSize));
+                    Lum::OS::display->GetFont(popupFontSize));
       text->SetAlignment(Lum::Text::centered);
 
-      button=new Lum::Button();
-      button->SetFlex(true,true);
-      button->SetLabel(text);
-      button->SetModel(models[i]);
-
-      array->Add(button);
+      array->Add(Lum::Button::Create(text,models[i],true,true));
     }
     panel->Add(array);
 
-    button=new Lum::Button();
-    button->SetFlex(true,false);
-    button->SetText(_(L"GAMEAREA_CLEAR",L"Clear"));
-    button->SetModel(models[0]);
-
-    panel->Add(button);
+    panel->Add(Lum::Button::Create(_(L"GAMEAREA_CLEAR",L"Clear"),models[0],true,false));
 
     SetMain(panel);
 
@@ -155,8 +143,7 @@ public:
       text=new Lum::Text();
       text->SetFlex(true,true);
       text->SetText(Lum::Base::NumberToWString(i+1),
-                    Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                              popupFontSize));
+                    Lum::OS::display->GetFont(popupFontSize));
       text->SetAlignment(Lum::Text::centered);
 
       toggle=new Lum::Toggle();
@@ -198,11 +185,9 @@ public:
 };
 
 GameArea::GameArea()
- : minFont(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                  Lum::OS::Display::fontScaleNormal)),
+ : minFont(Lum::OS::display->GetFont()),
    markFont(Lum::OS::display->GetFontByPixel(Lum::OS::Display::fontTypeProportional,7)),
-   font(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                  Lum::OS::Display::fontScaleCaption1)),
+   font(Lum::OS::display->GetFont(Lum::OS::Display::fontScaleCaption1)),
    presetColor(0.5,0.5,0.5,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
    focusBackgroundColor(0.95,0.95,0.95,Lum::OS::display->GetColor(Lum::OS::Display::fillColor)),
    markBackgroundColor(0.95,0.95,0.95,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
@@ -340,8 +325,7 @@ Lum::OS::Font* GameArea::FindFont(size_t size)
   bool             fits;
   size_t           fontSize;
 
-  font=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                 Lum::OS::Display::fontScaleNormal);
+  font=Lum::OS::display->GetFont();
   fontSize=font->pixelHeight+1;
 
   do {
@@ -393,17 +377,6 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
 
   size=(3+1)*1+(9+1)*1+9*boxSize;
 
-  // Fill region outside game area with background
-  if (size<width) {
-    DrawBackground(this->x+size,this->y,width-size,size);
-  }
-  if (size<height) {
-    DrawBackground(this->x,this->y+size,size,height-size);
-  }
-  if (size<width && size<height) {
-    DrawBackground(this->x+size,this->y+size,width-size,height-size);
-  }
-
   //
   // Draw game area
   //
