@@ -36,7 +36,6 @@
 #include <Lum/Label.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/Text.h>
 
 #include <Lum/Model/Action.h>
@@ -173,61 +172,48 @@ public:
 
   void PreInit()
   {
-    Lum::Array               *array;
-    Lum::Button              *button;
-    Lum::Combo               *combo;
-    Lum::Label               *label;
-    Lum::Model::ListTableRef table;
-    Lum::Panel               *horiz,*vert;
+    Lum::Array                 *array;
+    Lum::Combo                 *combo;
+    Lum::Label                 *label;
+    Lum::Model::StringTableRef pointsModel;
+    Lum::Panel                 *horiz,*vert;
 
-    horiz=new Lum::HPanel();
-    horiz->SetFlex(true,true);
+    horiz=Lum::HPanel::Create(true,true);
 
     gameArea->SetFlex(true,true);
     gameArea->SetModel(riddle,solution);
 
     horiz->Add(gameArea);
 
-    horiz->Add(new Lum::HSpace());
+    horiz->AddSpace();
 
-    vert=new Lum::VPanel();
-    vert->SetFlex(false,true);
+    vert=Lum::VPanel::Create(false,true);
 
     array=new Lum::Array();
     array->SetFlex(true,false);
     array->SetVerticalCount(1);
     array->SetSpace(true,false);
 
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(generateAction);
-    button->SetText(_(L"GENERATE",L"_Generate"));
-    array->Add(button);
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(solveAction);
-    button->SetText(_(L"SOLVE",L"_Solve"));
-    array->Add(button);
+    array->Add(Lum::Button::Create(_(L"GENERATE",L"_Generate"),generateAction,true,false));
+    array->Add(Lum::Button::Create(_(L"SOLVE",L"_Solve"),solveAction,true,false));
 
     vert->Add(array);
 
-    vert->Add(new Lum::VSpace());
+    vert->AddSpace();
 
-    label=new Lum::Label();
-    label->SetFlex(false,true);
+    label=Lum::Label::Create(false,true);
 
-    table=new Lum::Model::ListTable(1);
-    table->AppendString(L"2500");
-    table->AppendString(L"4000");
-    table->AppendString(L"8000");
-    table->AppendString(L"15000");
-    table->AppendString(L"25000");
+    pointsModel=new Lum::Model::StringTable();
+    pointsModel->Append(L"2500");
+    pointsModel->Append(L"4000");
+    pointsModel->Append(L"8000");
+    pointsModel->Append(L"15000");
+    pointsModel->Append(L"25000");
 
     combo=new Lum::TextEditCombo();
     combo->SetFlex(true,false);
     combo->SetModel(minimumPoints);
-    combo->SetTableModel(table);
+    combo->SetTableModel(pointsModel);
     dynamic_cast<Lum::TextEditCombo*>(combo)->GetString()->SetAlignment(Lum::String::right);
     label->AddLabel(_(L"POINTS_MIN",L"min. Points:"),combo);
 
